From: "tip-bot for Luis R. Rodriguez" <tipbot@zytor.com>
To: linux-tip-commits@vger.kernel.org
Cc: dvlasenk@redhat.com, rusty@rustcorp.com.au, peterz@infradead.org,
tglx@linutronix.de, brgerst@gmail.com, mcgrof@kernel.org,
torvalds@linux-foundation.org, linux-kernel@vger.kernel.org,
bp@alien8.de, luto@amacapital.net, hpa@zytor.com,
mingo@kernel.org
Subject: [tip:x86/boot] tools/lguest: Make lguest launcher use X86_SUBARCH_LGUEST explicitly
Date: Fri, 22 Apr 2016 02:49:53 -0700 [thread overview]
Message-ID: <tip-907bb655797427cc6498045d6977e77f8363fff7@git.kernel.org> (raw)
In-Reply-To: <1460592286-300-4-git-send-email-mcgrof@kernel.org>
Commit-ID: 907bb655797427cc6498045d6977e77f8363fff7
Gitweb: http://git.kernel.org/tip/907bb655797427cc6498045d6977e77f8363fff7
Author: Luis R. Rodriguez <mcgrof@kernel.org>
AuthorDate: Wed, 13 Apr 2016 17:04:33 -0700
Committer: Ingo Molnar <mingo@kernel.org>
CommitDate: Fri, 22 Apr 2016 10:29:00 +0200
tools/lguest: Make lguest launcher use X86_SUBARCH_LGUEST explicitly
Be explicit and make use of X86_SUBARCH_LGUEST directly.
Signed-off-by: Luis R. Rodriguez <mcgrof@kernel.org>
Acked-by: Rusty Russell <rusty@rustcorp.com.au>
Cc: Andy Lutomirski <luto@amacapital.net>
Cc: Borislav Petkov <bp@alien8.de>
Cc: Brian Gerst <brgerst@gmail.com>
Cc: Denys Vlasenko <dvlasenk@redhat.com>
Cc: H. Peter Anvin <hpa@zytor.com>
Cc: Linus Torvalds <torvalds@linux-foundation.org>
Cc: Peter Zijlstra <peterz@infradead.org>
Cc: Thomas Gleixner <tglx@linutronix.de>
Cc: andrew.cooper3@citrix.com
Cc: andriy.shevchenko@linux.intel.com
Cc: bigeasy@linutronix.de
Cc: boris.ostrovsky@oracle.com
Cc: david.vrabel@citrix.com
Cc: ffainelli@freebox.fr
Cc: george.dunlap@citrix.com
Cc: glin@suse.com
Cc: jgross@suse.com
Cc: jlee@suse.com
Cc: josh@joshtriplett.org
Cc: julien.grall@linaro.org
Cc: konrad.wilk@oracle.com
Cc: kozerkov@parallels.com
Cc: lenb@kernel.org
Cc: lguest@lists.ozlabs.org
Cc: linux-acpi@vger.kernel.org
Cc: lv.zheng@intel.com
Cc: matt@codeblueprint.co.uk
Cc: mbizon@freebox.fr
Cc: rjw@rjwysocki.net
Cc: robert.moore@intel.com
Cc: tiwai@suse.de
Cc: toshi.kani@hp.com
Cc: xen-devel@lists.xensource.com
Link: http://lkml.kernel.org/r/1460592286-300-4-git-send-email-mcgrof@kernel.org
Signed-off-by: Ingo Molnar <mingo@kernel.org>
---
tools/lguest/lguest.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/tools/lguest/lguest.c b/tools/lguest/lguest.c
index 80159e6..ff0aa580 100644
--- a/tools/lguest/lguest.c
+++ b/tools/lguest/lguest.c
@@ -3351,8 +3351,8 @@ int main(int argc, char *argv[])
/* Boot protocol version: 2.07 supports the fields for lguest. */
boot->hdr.version = 0x207;
- /* The hardware_subarch value of "1" tells the Guest it's an lguest. */
- boot->hdr.hardware_subarch = 1;
+ /* X86_SUBARCH_LGUEST tells the Guest it's an lguest. */
+ boot->hdr.hardware_subarch = X86_SUBARCH_LGUEST;
/* Tell the entry path not to try to reload segment registers. */
boot->hdr.loadflags |= KEEP_SEGMENTS;
next prev parent reply other threads:[~2016-04-22 9:51 UTC|newest]
Thread overview: 39+ messages / expand[flat|nested] mbox.gz Atom feed top
2016-04-14 0:04 [PATCH v6 00/16] x86: remove paravirt_enabled() Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 01/16] x86/boot: enumerate documentation for the x86 hardware_subarch Luis R. Rodriguez
2016-04-22 9:49 ` [tip:x86/boot] x86/boot: Enumerate " tip-bot for Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 02/16] x86/xen: use X86_SUBARCH_XEN for PV guest boots Luis R. Rodriguez
2016-04-22 9:49 ` [tip:x86/boot] x86/xen: Use " tip-bot for Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 03/16] tools/lguest: make lguest launcher use X86_SUBARCH_LGUEST explicitly Luis R. Rodriguez
2016-04-22 9:49 ` tip-bot for Luis R. Rodriguez [this message]
2016-04-14 0:04 ` [PATCH v6 04/16] x86/rtc: replace paravirt rtc check with platform legacy quirk Luis R. Rodriguez
2016-04-14 4:28 ` Juergen Gross
2016-04-22 9:50 ` [tip:x86/boot] x86/rtc: Replace " tip-bot for Luis R. Rodriguez
2024-04-03 15:34 ` [tip: x86/cleanups] x86/rtc: Remove unused intel-mid.h tip-bot2 for Andy Shevchenko
2016-04-14 0:04 ` [PATCH v6 05/16] x86, ACPI: move ACPI_FADT_NO_CMOS_RTC check to ACPI boot code Luis R. Rodriguez
2016-04-22 9:50 ` [tip:x86/boot] x86/ACPI: Move " tip-bot for Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 06/16] x86/init: use a platform legacy quirk for ebda Luis R. Rodriguez
2016-04-22 9:51 ` [tip:x86/boot] x86/init: Use a platform legacy quirk for EBDA tip-bot for Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 07/16] tools/lguest: force disable tboot and apm Luis R. Rodriguez
2016-04-22 9:51 ` [tip:x86/boot] tools/lguest: Force disable tboot and APM tip-bot for Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 08/16] apm32: remove paravirt_enabled() use Luis R. Rodriguez
2016-04-22 9:51 ` [tip:x86/boot] x86/apm32: Remove " tip-bot for Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 09/16] x86/tboot: remove paravirt_enabled() Luis R. Rodriguez
2016-04-22 9:52 ` [tip:x86/boot] x86/tboot: Remove paravirt_enabled() use tip-bot for Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 10/16] x86/cpu/intel: remove not needed paravirt_enabled() for f00f work around Luis R. Rodriguez
2016-04-22 9:52 ` [tip:x86/boot] x86/cpu/intel: Remove not needed paravirt_enabled() use for F00F " tip-bot for Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 11/16] pnpbios: replace paravirt_enabled() check with legacy device check Luis R. Rodriguez
2016-04-22 9:53 ` [tip:x86/boot] x86, drivers/pnpbios: Replace " tip-bot for Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 12/16] x86, ACPI: parse ACPI_FADT_LEGACY_DEVICES Luis R. Rodriguez
2016-04-22 9:53 ` [tip:x86/boot] x86/ACPI: Parse ACPI_FADT_LEGACY_DEVICES tip-bot for Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 13/16] x86/init: rename ebda code file Luis R. Rodriguez
2016-04-22 9:53 ` [tip:x86/boot] x86/init: Rename EBDA " tip-bot for Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 14/16] x86/paravirt: remove paravirt_enabled() Luis R. Rodriguez
2016-04-22 9:54 ` [tip:x86/boot] x86/paravirt: Remove paravirt_enabled() tip-bot for Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 15/16] x86/init: disable pnpbios for X86_SUBARCH_INTEL_MID Luis R. Rodriguez
2016-04-22 9:54 ` [tip:x86/boot] x86/init: Disable " tip-bot for Luis R. Rodriguez
2016-04-14 0:04 ` [PATCH v6 16/16] x86/init: disable pnpbios and rtc for X86_SUBARCH_CE4100 Luis R. Rodriguez
2016-04-22 9:54 ` [tip:x86/boot] x86/init: Disable " tip-bot for Luis R. Rodriguez
2016-04-14 0:13 ` [PATCH v6 05/16] x86, ACPI: move ACPI_FADT_NO_CMOS_RTC check to ACPI boot code Luis R. Rodriguez
2016-04-14 0:13 ` [PATCH v6 07/16] tools/lguest: force disable tboot and apm Luis R. Rodriguez
2016-04-14 0:13 ` [PATCH v6 12/16] x86, ACPI: parse ACPI_FADT_LEGACY_DEVICES Luis R. Rodriguez
2016-04-14 0:17 ` [PATCH v6 05/16] x86, ACPI: move ACPI_FADT_NO_CMOS_RTC check to ACPI boot code Luis R. Rodriguez
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tip-907bb655797427cc6498045d6977e77f8363fff7@git.kernel.org \
--to=tipbot@zytor.com \
--cc=bp@alien8.de \
--cc=brgerst@gmail.com \
--cc=dvlasenk@redhat.com \
--cc=hpa@zytor.com \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=luto@amacapital.net \
--cc=mcgrof@kernel.org \
--cc=mingo@kernel.org \
--cc=peterz@infradead.org \
--cc=rusty@rustcorp.com.au \
--cc=tglx@linutronix.de \
--cc=torvalds@linux-foundation.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Powered by JetHome